# pyBelt

PyBelt is a Python library to control the feelSpace naviBelt from your application. The feelSpace naviBelt is a device that provides tactile feedback using vibration motors located in a belt. The naviBelt can be controlled by an application via Bluetooth Low-Energy or USB.

The naviBelt can be used in various domains, for instance:
* navigation applications, 
* VR, 
* simulation, 
* research experiments that require tactile feedback,
* outdoor and video-games,
* applications that require tactile feedback to improve focus or attention.

## Installation

```
pip install pybelt
```

## Documentation

* [pyBelt documentation](https://github.com/feelSpace/pybelt/blob/main/docs/README.md)
* Developer page (coming soon)


## About feelSpace

* Learn more about feelSpace at [www.feelspace.de](https://www.feelspace.de/?lang=en)

## Copyright and license notice

Copyright 2020, feelSpace GmbH.

Licensed under the Apache License, Version 2.0: http://www.apache.org/licenses/LICENSE-2.0

**Note on using feelSpace Trademarks and Copyrights:**

*Attribution:* You must give appropriate credit to feelSpace GmbH when you use feelSpace products in a publicly disclosed derived work. For instance, you must reference feelSpace GmbH in publications, conferences or seminars when a feelSpace product has been used in the presented work.

*Endorsement or Sponsorship:* You may not use feelSpace name, feelSpace products’ name, and logos in a way that suggests an affiliation or endorsement by feelSpace GmbH of your derived work, except if it was explicitly communicated by feelSpace GmbH.
